# khwarizmi

A simple library for efficiently solving basic algebraic expressions.

# Brief intro

This library works in a similar way an interpreter does. Its singularity is that what it interprets is a special kind of language: **algebra**. 

It works with classes because algebraic properties are more similar to attributes of a thing than to variables or mere information. 

This library is currently under active development. It can be used, but bugs and errors can be expected.

# Requirements

The only requirement for using the library are having **Python 3.x** and **matplotlib library** installed (the last is installed by default in most GNU/Linux distros so no problems there).

# How?

Khwarizmi works by allowing you to treat your equations as instances of an algebraic class. Essentially, it lets you express your equations -simple strings- as rich algebraic objects with their own unique properties and methosd! It is fast, and it is simple. If you want to learn how to use it, check the Wiki and you'll be good to go in minutes!
    
    


    

    
